import { fail } from '@sveltejs/kit';
import type { RequestHandler } from './$types';
import { RecursiveCharacterTextSplitter } from 'langchain/text_splitter';
import { OpenAI } from 'langchain/llms';
import { loadSummarizationChain } from 'langchain/chains';

export const POST = (async ({ request, url }) => {
	try {
		const form = await request.formData();

		const file = form.get('file');
		if (!file) throw new Error('No prompt found in the request.');
		const text = await (file as Blob).text();

		const model = new OpenAI({ temperature: 0 });
		const textSplitter = new RecursiveCharacterTextSplitter({ chunkSize: 1000 });
		const docs = await textSplitter.createDocuments([text]);

		// This convenience function creates a document chain prompted to summarize a set of documents.
		const chain = loadSummarizationChain(model);
		const response = await chain.call({
			input_documents: docs
		});

		return new Response(JSON.stringify({ response: response.text }), {
			headers: {
				'Content-Type': 'application/json'
			}
		});
	} catch (err) {
		console.log(err);

		const appError = err as App.Error;
		console.log(appError.message);
		throw fail(500, { err: err });
	}
}) satisfies RequestHandler;
